@@ -1,10 +1,11 @@
-import json
 from datetime import datetime
 from enum import Enum
 from pathlib import Path
 
 import requests
 
+from python_ntfy._exceptions import MessageSendError
+
 
 class MessagePriority(Enum):
     """Ntfy message priority levels.
@@ -214,7 +215,7 @@ def send(
         dict: The response from the server.
 
     Raises:
-        ToDo
+        MessageSendError: If the message fails to send.
 
     Examples:
         >>> response = client.send(message="Example message")
@@ -243,20 +244,24 @@ def send(
     if schedule:
         headers["Delay"] = str(int(schedule.timestamp()))
 
-    return json.loads(
-        requests.post(
+    try:
+        response = requests.post(
             url=self.url,
             data=message,
             headers=headers,
             auth=self._auth,
             timeout=timeout_seconds,
-        ).text,
-    )
+        )
+        response.raise_for_status()
+        return response.json()
+    except requests.exceptions.RequestException as e:
+        error_message = f"Failed to send message: {e}"
+        raise MessageSendError(error_message) from e
 
 
 def send_file(
     self,
-    file: str,
+    file: str | Path,
     title: str | None = None,
     priority: MessagePriority = MessagePriority.DEFAULT,
     tags: list | None = None,
@@ -268,7 +273,7 @@ def send_file(
     """Sends a file to the server.
 
     Args:
-        file: The path to the file to send.
+        file: The file to send.
         title: The title of the file.
         priority: The priority of the message. Optional, defaults to MessagePriority.
         tags: A list of tags to attach to the message. Can be an emoji short code.
@@ -281,7 +286,7 @@ def send_file(
         dict: The response from the server.
 
     Raises:
-        ToDo
+        MessageSendError: If the message fails to send.
 
     Examples:
         >>> response = client.send_file(file="example.txt")
@@ -291,9 +296,17 @@ def send_file(
     if tags is None:
         tags = []
 
+    try:
+        data = Path(file).read_bytes()
+    except Exception as e:
+        error_message = f"Failed to read file: {e}"
+        raise MessageSendError(error_message) from e
+
+    filename = Path(file).name
+
     headers = {
         "Title": str(title),
-        "Filename": file.split("/")[-1],
+        "Filename": filename,
         "Priority": priority.value,
         "Tags": ",".join(tags),
         "Actions": " ; ".join([action.to_header() for action in actions]),
@@ -305,13 +318,16 @@ def send_file(
     if schedule:
         headers["Delay"] = str(int(schedule.timestamp()))
 
-    with Path(file).open("rb") as f:
-        return json.loads(
-            requests.post(
-                url=self.url,
-                data=f,
-                headers=headers,
-                auth=self._auth,
-                timeout=timeout_seconds,
-            ).text,
+    try:
+        response = requests.post(
+            url=self.url,
+            data=data,
+            headers=headers,
+            auth=self._auth,
+            timeout=timeout_seconds,
         )
+        response.raise_for_status()
+        return response.json()
+    except requests.exceptions.RequestException as e:
+        error_message = f"Failed to send file: {e}"
+        raise MessageSendError(error_message) from e
